@@ -516,6 +516,10 @@ def show_preservation(doi, literal=False, no_issn=False):
             log.info(f"[red]Not preserved:[/] in {key}", extra={"markup": True})
 
 
+def test():
+    print("RUNNING")
+
+
 if __name__ == "__main__":
     cli.add_command(clear_cache)
     cli.add_command(draw_graphs)
