@@ -1,13 +1,10 @@
 import hashlib
-import json
 import logging
-import os
 from collections import defaultdict, OrderedDict
 from datetime import date
-from datetime import timedelta
 from typing import DefaultDict, Any
 
-from crossref.restful import MaxOffsetError
+from caseconverter import kebabcase
 
 SAMPLES_BUCKET = "samples.research.crossref.org"
 SAMPLES_PATH = "members-works/2023-03-05/samples/"
@@ -200,7 +197,7 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
     Processes samples for a single member
     :param samples: the samples to process
     :param sample_path: the path of the sample
-    :param verbose: whether or not to print the sample
+    :param verbose: whether to print the sample
     :return: a dictionary of preservation statistics
     """
     from constants import archives
@@ -252,7 +249,12 @@ def process_member_sample(samples, sample_path, verbose=False) -> dict:
                     f"{ANNOTATION_PATH}/works/{md5_doi}/{ANNOTATION_FILENAME}"
                 )
 
-                preserved_json = {}
+                preserved_json = {
+                    "about": {
+                        "DOI": doi["DOI"],
+                        "date-generated": str(datetime.now()),
+                    }
+                }
 
                 # increment the sample count
                 overall_status["sample-count"] += 1
@@ -406,6 +408,10 @@ def push_json_to_s3(
     import json
     import logging
 
+    if verbose:
+        logging.info("Normalizing JSON keys")
+        json_obj = normalize_json_keys(json_obj)
+
     if verbose:
         logging.info(f"Writing JSON to S3 bucket {bucket} at path {path}")
 
@@ -413,6 +419,29 @@ def push_json_to_s3(
     obj.put(Body=json.dumps(json_obj))
 
 
+def normalize_json_keys(json_obj: dict) -> dict:
+    """
+    Always normalize keys to kebab case
+    :param json_obj: the JSON object to normalize
+    :return: a new JSON object with normalized keys
+    """
+    for key in json_obj:
+        json_obj[normalize_json_key(key)] = json_obj.pop(key)
+
+    return json_obj
+
+
+def normalize_json_key(key: str) -> str:
+    """
+    Normalize keys to kebab case
+    :param key: the key to normalize
+    :return: the normalized key
+    """
+    # while it seems overkill to have this as a separate function,
+    # it's useful in other contexts, too, to have it on its own
+    return kebabcase(key)
+
+
 def process_sample(
     annotation_bucket,
     annotation_filename,
@@ -431,7 +460,7 @@ def process_sample(
     :param samples_bucket: the samples bucket
     :param samples_path: the samples path
     :param member_id: the member id
-    :param verbose: whether or not to print status messages
+    :param verbose: whether to print status messages
     :param code_bucket: the code bucket where settings are located
     :return:
     """
@@ -871,7 +900,6 @@ def member_position(members=None, limit=0, member_id=None):
 
 def rescore_all(members=None, limit=0):
     import boto3
-    import logging
     from rich.progress import track
 
     s3client = boto3.client("s3")
@@ -920,7 +948,6 @@ def get_annotation(
     )
 
     from io import StringIO
-    import logging
     import json
 
     with StringIO(data) as json_file:
